@@ -6,7 +6,7 @@ from graphviz import Digraph
 from hbutils.reflection import dynamic_call, raising
 
 from ..func import method_treelize, MISSING_NOT_ALLOW, func_treelize
-from ..tree import TreeValue, jsonify, clone, typetrans, mapping, mask, filter_, reduce_, union, graphics
+from ..tree import TreeValue, jsonify, clone, typetrans, mapping, mask, filter_, reduce_, union, graphics, walk
 from ..tree import rise as rise_func
 from ..tree import subside as subside_func
 
@@ -147,13 +147,14 @@ def general_tree_value(base: Optional[Mapping[str, Any]] = None,
             return typetrans(self, clazz)
 
         @_decorate_method
-        def map(self, mapper):
+        def map(self, mapper, delayed=False):
             """
             Overview:
                 Do mapping on every value in this tree.
 
             Arguments:
                 - func (:obj:): Function for mapping
+                - delayed (:obj:`bool`): Enable delayed mode for this mapping.
 
             Returns:
                 - tree (:obj:`_TreeValue`): Mapped tree value object.
@@ -164,7 +165,7 @@ def general_tree_value(base: Optional[Mapping[str, Any]] = None,
                 >>> t.map(lambda: 1)        # FastTreeValue({'a': 1, 'b': 1, 'x': {'c': 1, 'd': 1}})
                 >>> t.map(lambda x, p: p)   # FastTreeValue({'a': ('a',), 'b': ('b',), 'x': {'c': ('x', 'c'), 'd': ('x', 'd')}})
             """
-            return mapping(self, mapper)
+            return mapping(self, mapper, delayed)
 
         @_decorate_method
         def mask(self, mask_: TreeValue, remove_empty: bool = True):
@@ -208,6 +209,39 @@ def general_tree_value(base: Optional[Mapping[str, Any]] = None,
             """
             return filter_(self, func, remove_empty)
 
+        @_decorate_method
+        def walk(self):
+            """
+            Overview:
+                Walk the values and nodes in the tree.
+                The order of walk is not promised, if you need the ordered walking result, \
+                just use function ``sorted`` at the outer side of :func:`walk`.
+
+            Returns:
+                - iter: Iterator to walk the given tree, contains 2 items, the 1st one is the full \
+                    path of the node, the 2nd one is the value.
+
+            Examples::
+                >>> from treevalue import FastTreeValue, walk
+                >>> tv1 = FastTreeValue({'a': 1, 'b': 2, 'c': {'x': 2, 'y': 2}})
+                >>> for k, v in tv1.walk():
+                ...     print(k, v)
+                () <TreeValue 0x7f2a88eb1a20>
+                ├── a --> 1
+                ├── b --> 2
+                └── c --> <TreeValue 0x7f2a88eb19b0>
+                    ├── x --> 2
+                    └── y --> 2
+                ('a',) 1
+                ('b',) 2
+                ('c',) <TreeValue 0x7f2a88eb19b0>
+                ├── x --> 2
+                └── y --> 2
+                ('c', 'x') 2
+                ('c', 'y') 2
+            """
+            return walk(self)
+
         @_decorate_method
         def reduce(self, func):
             """
@@ -308,9 +342,8 @@ def general_tree_value(base: Optional[Mapping[str, Any]] = None,
         @classmethod
         @_decorate_method
         def func(cls, mode: str = 'strict', inherit: bool = True,
-                 missing: Union[Any, Callable] = MISSING_NOT_ALLOW,
-                 subside: Union[Mapping, bool, None] = None,
-                 rise: Union[Mapping, bool, None] = None):
+                 missing: Union[Any, Callable] = MISSING_NOT_ALLOW, delayed: bool = False,
+                 subside: Union[Mapping, bool, None] = None, rise: Union[Mapping, bool, None] = None):
             """
             Overview:
                 Wrap a common function to tree-supported function based on this type.
@@ -320,6 +353,8 @@ def general_tree_value(base: Optional[Mapping[str, Any]] = None,
                 - inherit (:obj:`bool`): Allow inherit in wrapped function, default is `True`.
                 - missing (:obj:`Union[Any, Callable]`): Missing value or lambda generator of when missing, \
                     default is `MISSING_NOT_ALLOW`, which means raise `KeyError` when missing detected.
+                - delayed (:obj:`bool`): Enable delayed mode or not, the calculation will be delayed when enabled, \
+                    default is ``False``, which means to all the calculation at once.
                 - subside (:obj:`Union[Mapping, bool, None]`): Subside enabled to function's arguments or not, \
                     and subside configuration, default is `None` which means do not use subside. \
                     When subside is `True`, it will use all the default arguments in `subside` function.
@@ -343,7 +378,7 @@ def general_tree_value(base: Optional[Mapping[str, Any]] = None,
                 >>> ssum(1, 2)    # 3
                 >>> ssum(t1, t2)  # FastTreeValue({'a': 12, 'b': 24, 'x': {'c': 36, 'd': 9}})
             """
-            return func_treelize(mode, cls, inherit, missing, subside, rise)
+            return func_treelize(mode, cls, inherit, missing, delayed, subside, rise)
 
         @classmethod
         @_decorate_method
