@@ -1,7 +1,7 @@
-from .flatten import flatten, unflatten
+from .flatten import flatten, unflatten, flatten_values, flatten_keys
 from .functional import mapping, filter_, mask, reduce_
 from .graph import graphics
 from .io import loads, load, dumps, dump
 from .service import jsonify, clone, typetrans, walk
 from .structural import subside, union, rise
-from .tree import TreeValue
+from .tree import TreeValue, delayed
